==> monet-1.0.31-sources.jar: io/intino/monet/box/ui/displays/templates/AbstractCheckListWizardStepPackageFile.java <==
package io.intino.monet.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.monet.box.ui.*;

import io.intino.monet.box.MonetBox;

import io.intino.monet.box.ui.displays.templates.*;






import io.intino.monet.box.ui.displays.items.*;

import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractCheckListWizardStepPackageFile<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public _133_1_1744068534 _133_1_1744068534;
	public CheckListWizardStepPackageFile._133_1_1744068534. Data data;

    public AbstractCheckListWizardStepPackageFile(B box) {
        super(box);
        id("checkListWizardStepPackageFile");
    }

    @Override
	public void init() {
		super.init();
		if (_133_1_1744068534 == null) _133_1_1744068534 = register(new _133_1_1744068534(box()).<_133_1_1744068534>id("a407648298").owner(AbstractCheckListWizardStepPackageFile.this));
		if (_133_1_1744068534 != null) data = _133_1_1744068534.data;
	}

    @Override
    public void remove() {
        super.remove();
	    if (_133_1_1744068534 != null) _133_1_1744068534.unregister();
	}

	public class _133_1_1744068534 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public CheckListWizardStepPackageFile._133_1_1744068534. Data data;

		public _133_1_1744068534(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (data == null) data = register(new Data(box()).<Data>id("a_1710561705").owner(AbstractCheckListWizardStepPackageFile.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (data != null) data.unregister();
		}

		public class Data extends io.intino.alexandria.ui.displays.components.FileEditable<io.intino.alexandria.ui.displays.notifiers.FileEditableNotifier, B>  {

			public Data(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
		}
	}
}

==> monet-1.0.58-sources.jar: io/intino/monet/box/ui/displays/templates/AbstractCheckListWizardStepPackageFile.java <==
package io.intino.monet.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.monet.box.ui.*;

import io.intino.monet.box.MonetBox;

import io.intino.monet.box.ui.displays.templates.*;






import io.intino.monet.box.ui.displays.items.*;

import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractCheckListWizardStepPackageFile<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public _137_1_1938957610 _137_1_1938957610;
	public CheckListWizardStepPackageFile._137_1_1938957610. Data data;

    public AbstractCheckListWizardStepPackageFile(B box) {
        super(box);
        id("checkListWizardStepPackageFile");
    }

    @Override
	public void init() {
		super.init();
		if (_137_1_1938957610 == null) _137_1_1938957610 = register(new _137_1_1938957610(box()).<_137_1_1938957610>id("a1129386499").owner(AbstractCheckListWizardStepPackageFile.this));
		if (_137_1_1938957610 != null) data = _137_1_1938957610.data;
	}

    @Override
    public void remove() {
        super.remove();
	    if (_137_1_1938957610 != null) _137_1_1938957610.unregister();
	}

	public class _137_1_1938957610 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public CheckListWizardStepPackageFile._137_1_1938957610. Data data;

		public _137_1_1938957610(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (data == null) data = register(new Data(box()).<Data>id("a965712339").owner(AbstractCheckListWizardStepPackageFile.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (data != null) data.unregister();
		}

		public class Data extends io.intino.alexandria.ui.displays.components.FileEditable<io.intino.alexandria.ui.displays.notifiers.FileEditableNotifier, B>  {

			public Data(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
		}
	}
}
